import 'package:flutter/material.dart';
import 'package:flutter_custom_toolbox/flutter_toolbox.dart';

import 'package:stopmotion/ui/pages/editor.dart';
import 'package:stopmotion/ui/pages/home.dart';
import 'package:stopmotion/ui/pages/player.dart';

class ActivityPageItem {
  final Icon icon;
  final Widget page;
  final String code;

  const ActivityPageItem({
    required this.icon,
    required this.page,
    required this.code,
  });
}

class ActivityPage {
  static const indexHome = 0;
  static const pageHome = ActivityPageItem(
    icon: Icon(UniconsLine.home),
    page: PageHome(),
    code: 'page_home',
  );

  static const indexEditor = 1;
  static const pageEditor = ActivityPageItem(
    icon: Icon(UniconsLine.setting),
    page: PageEditor(),
    code: 'page_editor',
  );

  static const indexPlayer = 2;
  static const pagePlayer = ActivityPageItem(
    icon: Icon(UniconsLine.info_circle),
    page: PagePlayer(),
    code: 'page_player',
  );

  static Map<int, ActivityPageItem> items = {
    indexHome: pageHome,
    indexEditor: pageEditor,
    indexPlayer: pagePlayer,
  };

  static bool isIndexAllowed(int pageIndex) {
    return items.keys.contains(pageIndex);
  }

  static ActivityPageItem getPageItem(int pageIndex) {
    return items[pageIndex] ?? pageHome;
  }

  static Widget getPageWidget(int pageIndex) {
    return items[pageIndex]?.page ?? pageHome.page;
  }

  static int itemsCount = ActivityPage.items.length;
}
