import 'package:flutter/material.dart';
import 'package:flutter_custom_toolbox/flutter_toolbox.dart';

import 'package:stopmotion/config/screen.dart';
import 'package:stopmotion/cubit/activity_cubit.dart';
import 'package:stopmotion/cubit/nav_cubit_screens.dart';

class GlobalAppBar extends StatelessWidget implements PreferredSizeWidget {
  const GlobalAppBar({super.key});

  @override
  Widget build(BuildContext context) {
    return BlocBuilder<ActivityCubit, ActivityState>(
      builder: (BuildContext context, ActivityState activityState) {
        return BlocBuilder<NavCubitScreen, int>(
          builder: (BuildContext context, int screenIndex) {
            final List<Widget> menuActions = [];

            if (screenIndex == Screen.indexActivity) {
              // go to Settings page
              menuActions.add(ElevatedButton(
                onPressed: () {
                  BlocProvider.of<NavCubitScreen>(context).goToSettingsPage();
                },
                style: ElevatedButton.styleFrom(
                  shape: const CircleBorder(),
                ),
                child: Screen.screenSettings.icon,
              ));

              // go to About page
              menuActions.add(ElevatedButton(
                onPressed: () {
                  BlocProvider.of<NavCubitScreen>(context).goToAboutPage();
                },
                style: ElevatedButton.styleFrom(
                  shape: const CircleBorder(),
                ),
                child: Screen.screenAbout.icon,
              ));
            } else {
              // back to Home page
              menuActions.add(ElevatedButton(
                onPressed: () {
                  BlocProvider.of<NavCubitScreen>(context).goToActivityPage();
                },
                style: ElevatedButton.styleFrom(
                  shape: const CircleBorder(),
                ),
                child: Screen.screenActivity.icon,
              ));
            }

            return AppBar(
              title: const AppHeader(text: 'app_name'),
              actions: menuActions,
            );
          },
        );
      },
    );
  }

  @override
  Size get preferredSize => const Size.fromHeight(50);
}
